@@ -1,12 +1,13 @@
 /***************************************************************
- *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.6.0                   *
+ *                    simula.plus@cemes.fr                     *
+ *                   GNU/linux version 3.0.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2006,2009,2010 COLLARD Christophe
- * copyright © 2006,2009,2010 Centre National de la Recherche Scientifique
+ * copyright © 2006,2009,2010,2012 COLLARD Christophe
+ * copyright © 2006,2009,2010,2012 Centre National de la Recherche Scientifique
  * copyright © 2006,2009,2010 Arts et Métiers ParisTech
  * copyright © 2006,2009,2010 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2012 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*
@@ -32,44 +33,44 @@
 #error Must use C++ for the type interface.
 #endif
 
-#if !defined (__MPI_H)
+#ifndef __mpi_h
 #include <mpi.h>
 #endif
 
-#if !defined(__IOSTREAM_H)
+#ifndef __iostream
 #include <iostream>
 #endif
 
-#if !defined(__FSTREAM_H)
+#ifndef __fstream
 #include <fstream>
 #endif
 
-#if !defined(__STDIO_H)
+#ifndef __stdio_h
 #include <stdio.h>
 #endif
 
-#if !defined (__STDLIB_H)
+#ifndef __stdlib_h
 #include <stdlib.h>
 #endif
 
-#if !defined(__TIME_H)
+#ifndef __time_h
 #include <time.h>
 #endif
 
-#if !defined(__COLORS_H)
-#include "colors.h"
+#ifndef __colors_hpp
+#include "colors.hpp"
 #endif
 
-#if !defined(__BROADCAST_TEST_H)
-#include "broadcast-test.h"
+#ifndef __broadcast_test_hpp
+#include "broadcast-test.hpp"
 #endif
 
 //#if !defined(__SECURE_BROADCAST_TEST_H)
 //#include "secure broadcast-test.h"
 //#endif
 
-#if !defined(__SEND_RECEIVE_TEST_H)
-#include "send receive-test.h"
+#ifndef __send_receive_test_hpp
+#include "send receive-test.hpp"
 #endif
 
 using namespace std;
